summaryrefslogtreecommitdiff
path: root/samples
diff options
context:
space:
mode:
authorlsces <lester@lsces.co.uk>2014-06-07 07:46:37 +0100
committerlsces <lester@lsces.co.uk>2014-06-07 07:46:37 +0100
commite7fc08e5cd9575c05f1dc05af451fb332ff1f277 (patch)
tree3ebf38e62e610423456a83a1ef5476013c86d7a2 /samples
parente530e13afe58ed0644b6a7f177b679926c137609 (diff)
downloadckeditor-e7fc08e5cd9575c05f1dc05af451fb332ff1f277.tar.gz
ckeditor-e7fc08e5cd9575c05f1dc05af451fb332ff1f277.tar.bz2
ckeditor-e7fc08e5cd9575c05f1dc05af451fb332ff1f277.zip
Upgrade to version 4.3
Diffstat (limited to 'samples')
-rwxr-xr-x[-rw-r--r--]samples/api.html414
-rwxr-xr-x[-rw-r--r--]samples/assets/outputxhtml/outputxhtml.css408
-rwxr-xr-x[-rw-r--r--]samples/assets/posteddata.php118
-rwxr-xr-x[-rw-r--r--]samples/assets/uilanguages/languages.js92
-rwxr-xr-x[-rw-r--r--]samples/index.html224
-rwxr-xr-x[-rw-r--r--]samples/sample.css695
-rwxr-xr-x[-rw-r--r--]samples/sample.js84
-rwxr-xr-x[-rw-r--r--]samples/sample_posteddata.php32
8 files changed, 1030 insertions, 1037 deletions
diff --git a/samples/api.html b/samples/api.html
index 9d51ef7..fc14165 100644..100755
--- a/samples/api.html
+++ b/samples/api.html
@@ -1,207 +1,207 @@
-<!DOCTYPE html>
-<!--
-Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.html or http://ckeditor.com/license
--->
-<html>
-<head>
- <meta charset="utf-8">
- <title>API Usage &mdash; CKEditor Sample</title>
- <script src="../ckeditor.js"></script>
- <link href="sample.css" rel="stylesheet">
- <script>
-
-// The instanceReady event is fired, when an instance of CKEditor has finished
-// its initialization.
-CKEDITOR.on( 'instanceReady', function( ev ) {
- // Show the editor name and description in the browser status bar.
- document.getElementById( 'eMessage' ).innerHTML = 'Instance <code>' + ev.editor.name + '<\/code> loaded.';
-
- // Show this sample buttons.
- document.getElementById( 'eButtons' ).style.display = 'block';
-});
-
-function InsertHTML() {
- // Get the editor instance that we want to interact with.
- var editor = CKEDITOR.instances.editor1;
- var value = document.getElementById( 'htmlArea' ).value;
-
- // Check the active editing mode.
- if ( editor.mode == 'wysiwyg' )
- {
- // Insert HTML code.
- // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-insertHtml
- editor.insertHtml( value );
- }
- else
- alert( 'You must be in WYSIWYG mode!' );
-}
-
-function InsertText() {
- // Get the editor instance that we want to interact with.
- var editor = CKEDITOR.instances.editor1;
- var value = document.getElementById( 'txtArea' ).value;
-
- // Check the active editing mode.
- if ( editor.mode == 'wysiwyg' )
- {
- // Insert as plain text.
- // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-insertText
- editor.insertText( value );
- }
- else
- alert( 'You must be in WYSIWYG mode!' );
-}
-
-function SetContents() {
- // Get the editor instance that we want to interact with.
- var editor = CKEDITOR.instances.editor1;
- var value = document.getElementById( 'htmlArea' ).value;
-
- // Set editor contents (replace current contents).
- // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-setData
- editor.setData( value );
-}
-
-function GetContents() {
- // Get the editor instance that you want to interact with.
- var editor = CKEDITOR.instances.editor1;
-
- // Get editor contents
- // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-getData
- alert( editor.getData() );
-}
-
-function ExecuteCommand( commandName ) {
- // Get the editor instance that we want to interact with.
- var editor = CKEDITOR.instances.editor1;
-
- // Check the active editing mode.
- if ( editor.mode == 'wysiwyg' )
- {
- // Execute the command.
- // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-execCommand
- editor.execCommand( commandName );
- }
- else
- alert( 'You must be in WYSIWYG mode!' );
-}
-
-function CheckDirty() {
- // Get the editor instance that we want to interact with.
- var editor = CKEDITOR.instances.editor1;
- // Checks whether the current editor contents present changes when compared
- // to the contents loaded into the editor at startup
- // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-checkDirty
- alert( editor.checkDirty() );
-}
-
-function ResetDirty() {
- // Get the editor instance that we want to interact with.
- var editor = CKEDITOR.instances.editor1;
- // Resets the "dirty state" of the editor (see CheckDirty())
- // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-resetDirty
- editor.resetDirty();
- alert( 'The "IsDirty" status has been reset' );
-}
-
-function Focus() {
- CKEDITOR.instances.editor1.focus();
-}
-
-function onFocus() {
- document.getElementById( 'eMessage' ).innerHTML = '<b>' + this.name + ' is focused </b>';
-}
-
-function onBlur() {
- document.getElementById( 'eMessage' ).innerHTML = this.name + ' lost focus';
-}
-
- </script>
-
-</head>
-<body>
- <h1 class="samples">
- <a href="index.html">CKEditor Samples</a> &raquo; Using CKEditor JavaScript API
- </h1>
- <div class="description">
- <p>
- This sample shows how to use the
- <a class="samples" href="http://docs.ckeditor.com/#!/api/CKEDITOR.editor">CKEditor JavaScript API</a>
- to interact with the editor at runtime.
- </p>
- <p>
- For details on how to create this setup check the source code of this sample page.
- </p>
- </div>
-
- <!-- This <div> holds alert messages to be display in the sample page. -->
- <div id="alerts">
- <noscript>
- <p>
- <strong>CKEditor requires JavaScript to run</strong>. In a browser with no JavaScript
- support, like yours, you should still see the contents (HTML data) and you should
- be able to edit it normally, without a rich editor interface.
- </p>
- </noscript>
- </div>
- <form action="../../../samples/sample_posteddata.php" method="post">
- <textarea cols="100" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
-
- <script>
- // Replace the <textarea id="editor1"> with an CKEditor instance.
- CKEDITOR.replace( 'editor1', {
- on: {
- focus: onFocus,
- blur: onBlur,
-
- // Check for availability of corresponding plugins.
- pluginsLoaded: function( evt ) {
- var doc = CKEDITOR.document, ed = evt.editor;
- if ( !ed.getCommand( 'bold' ) )
- doc.getById( 'exec-bold' ).hide();
- if ( !ed.getCommand( 'link' ) )
- doc.getById( 'exec-link' ).hide();
- }
- }
- });
- </script>
-
- <p id="eMessage">
- </p>
-
- <div id="eButtons" style="display: none">
- <input id="exec-bold" onclick="ExecuteCommand('bold');" type="button" value="Execute &quot;bold&quot; Command">
- <input id="exec-link" onclick="ExecuteCommand('link');" type="button" value="Execute &quot;link&quot; Command">
- <input onclick="Focus();" type="button" value="Focus">
- <br><br>
- <input onclick="InsertHTML();" type="button" value="Insert HTML">
- <input onclick="SetContents();" type="button" value="Set Editor Contents">
- <input onclick="GetContents();" type="button" value="Get Editor Contents (XHTML)">
- <br>
- <textarea cols="100" id="htmlArea" rows="3">&lt;h2&gt;Test&lt;/h2&gt;&lt;p&gt;This is some &lt;a href="/Test1.html"&gt;sample&lt;/a&gt; HTML code.&lt;/p&gt;</textarea>
- <br>
- <br>
- <input onclick="InsertText();" type="button" value="Insert Text">
- <br>
- <textarea cols="100" id="txtArea" rows="3"> First line with some leading whitespaces.
-
-Second line of text preceded by two line breaks.</textarea>
- <br>
- <br>
- <input onclick="CheckDirty();" type="button" value="checkDirty()">
- <input onclick="ResetDirty();" type="button" value="resetDirty()">
- </div>
- </form>
- <div id="footer">
- <hr>
- <p>
- CKEditor - The text editor for the Internet - <a class="samples" href="http://ckeditor.com/">http://ckeditor.com</a>
- </p>
- <p id="copy">
- Copyright &copy; 2003-2013, <a class="samples" href="http://cksource.com/">CKSource</a> - Frederico
- Knabben. All rights reserved.
- </p>
- </div>
-</body>
-</html>
+<!DOCTYPE html>
+<!--
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or http://ckeditor.com/license
+-->
+<html>
+<head>
+ <meta charset="utf-8">
+ <title>API Usage &mdash; CKEditor Sample</title>
+ <script src="../ckeditor.js"></script>
+ <link href="sample.css" rel="stylesheet">
+ <script>
+
+// The instanceReady event is fired, when an instance of CKEditor has finished
+// its initialization.
+CKEDITOR.on( 'instanceReady', function( ev ) {
+ // Show the editor name and description in the browser status bar.
+ document.getElementById( 'eMessage' ).innerHTML = 'Instance <code>' + ev.editor.name + '<\/code> loaded.';
+
+ // Show this sample buttons.
+ document.getElementById( 'eButtons' ).style.display = 'block';
+});
+
+function InsertHTML() {
+ // Get the editor instance that we want to interact with.
+ var editor = CKEDITOR.instances.editor1;
+ var value = document.getElementById( 'htmlArea' ).value;
+
+ // Check the active editing mode.
+ if ( editor.mode == 'wysiwyg' )
+ {
+ // Insert HTML code.
+ // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-insertHtml
+ editor.insertHtml( value );
+ }
+ else
+ alert( 'You must be in WYSIWYG mode!' );
+}
+
+function InsertText() {
+ // Get the editor instance that we want to interact with.
+ var editor = CKEDITOR.instances.editor1;
+ var value = document.getElementById( 'txtArea' ).value;
+
+ // Check the active editing mode.
+ if ( editor.mode == 'wysiwyg' )
+ {
+ // Insert as plain text.
+ // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-insertText
+ editor.insertText( value );
+ }
+ else
+ alert( 'You must be in WYSIWYG mode!' );
+}
+
+function SetContents() {
+ // Get the editor instance that we want to interact with.
+ var editor = CKEDITOR.instances.editor1;
+ var value = document.getElementById( 'htmlArea' ).value;
+
+ // Set editor contents (replace current contents).
+ // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-setData
+ editor.setData( value );
+}
+
+function GetContents() {
+ // Get the editor instance that you want to interact with.
+ var editor = CKEDITOR.instances.editor1;
+
+ // Get editor contents
+ // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-getData
+ alert( editor.getData() );
+}
+
+function ExecuteCommand( commandName ) {
+ // Get the editor instance that we want to interact with.
+ var editor = CKEDITOR.instances.editor1;
+
+ // Check the active editing mode.
+ if ( editor.mode == 'wysiwyg' )
+ {
+ // Execute the command.
+ // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-execCommand
+ editor.execCommand( commandName );
+ }
+ else
+ alert( 'You must be in WYSIWYG mode!' );
+}
+
+function CheckDirty() {
+ // Get the editor instance that we want to interact with.
+ var editor = CKEDITOR.instances.editor1;
+ // Checks whether the current editor contents present changes when compared
+ // to the contents loaded into the editor at startup
+ // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-checkDirty
+ alert( editor.checkDirty() );
+}
+
+function ResetDirty() {
+ // Get the editor instance that we want to interact with.
+ var editor = CKEDITOR.instances.editor1;
+ // Resets the "dirty state" of the editor (see CheckDirty())
+ // http://docs.ckeditor.com/#!/api/CKEDITOR.editor-method-resetDirty
+ editor.resetDirty();
+ alert( 'The "IsDirty" status has been reset' );
+}
+
+function Focus() {
+ CKEDITOR.instances.editor1.focus();
+}
+
+function onFocus() {
+ document.getElementById( 'eMessage' ).innerHTML = '<b>' + this.name + ' is focused </b>';
+}
+
+function onBlur() {
+ document.getElementById( 'eMessage' ).innerHTML = this.name + ' lost focus';
+}
+
+ </script>
+
+</head>
+<body>
+ <h1 class="samples">
+ <a href="index.html">CKEditor Samples</a> &raquo; Using CKEditor JavaScript API
+ </h1>
+ <div class="description">
+ <p>
+ This sample shows how to use the
+ <a class="samples" href="http://docs.ckeditor.com/#!/api/CKEDITOR.editor">CKEditor JavaScript API</a>
+ to interact with the editor at runtime.
+ </p>
+ <p>
+ For details on how to create this setup check the source code of this sample page.
+ </p>
+ </div>
+
+ <!-- This <div> holds alert messages to be display in the sample page. -->
+ <div id="alerts">
+ <noscript>
+ <p>
+ <strong>CKEditor requires JavaScript to run</strong>. In a browser with no JavaScript
+ support, like yours, you should still see the contents (HTML data) and you should
+ be able to edit it normally, without a rich editor interface.
+ </p>
+ </noscript>
+ </div>
+ <form action="../../../samples/sample_posteddata.php" method="post">
+ <textarea cols="100" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
+
+ <script>
+ // Replace the <textarea id="editor1"> with an CKEditor instance.
+ CKEDITOR.replace( 'editor1', {
+ on: {
+ focus: onFocus,
+ blur: onBlur,
+
+ // Check for availability of corresponding plugins.
+ pluginsLoaded: function( evt ) {
+ var doc = CKEDITOR.document, ed = evt.editor;
+ if ( !ed.getCommand( 'bold' ) )
+ doc.getById( 'exec-bold' ).hide();
+ if ( !ed.getCommand( 'link' ) )
+ doc.getById( 'exec-link' ).hide();
+ }
+ }
+ });
+ </script>
+
+ <p id="eMessage">
+ </p>
+
+ <div id="eButtons" style="display: none">
+ <input id="exec-bold" onclick="ExecuteCommand('bold');" type="button" value="Execute &quot;bold&quot; Command">
+ <input id="exec-link" onclick="ExecuteCommand('link');" type="button" value="Execute &quot;link&quot; Command">
+ <input onclick="Focus();" type="button" value="Focus">
+ <br><br>
+ <input onclick="InsertHTML();" type="button" value="Insert HTML">
+ <input onclick="SetContents();" type="button" value="Set Editor Contents">
+ <input onclick="GetContents();" type="button" value="Get Editor Contents (HTML)">
+ <br>
+ <textarea cols="100" id="htmlArea" rows="3">&lt;h2&gt;Test&lt;/h2&gt;&lt;p&gt;This is some &lt;a href="/Test1.html"&gt;sample&lt;/a&gt; HTML code.&lt;/p&gt;</textarea>
+ <br>
+ <br>
+ <input onclick="InsertText();" type="button" value="Insert Text">
+ <br>
+ <textarea cols="100" id="txtArea" rows="3"> First line with some leading whitespaces.
+
+Second line of text preceded by two line breaks.</textarea>
+ <br>
+ <br>
+ <input onclick="CheckDirty();" type="button" value="checkDirty()">
+ <input onclick="ResetDirty();" type="button" value="resetDirty()">
+ </div>
+ </form>
+ <div id="footer">
+ <hr>
+ <p>
+ CKEditor - The text editor for the Internet - <a class="samples" href="http://ckeditor.com/">http://ckeditor.com</a>
+ </p>
+ <p id="copy">
+ Copyright &copy; 2003-2013, <a class="samples" href="http://cksource.com/">CKSource</a> - Frederico
+ Knabben. All rights reserved.
+ </p>
+ </div>
+</body>
+</html>
diff --git a/samples/assets/outputxhtml/outputxhtml.css b/samples/assets/outputxhtml/outputxhtml.css
index eab9374..9c90a2a 100644..100755
--- a/samples/assets/outputxhtml/outputxhtml.css
+++ b/samples/assets/outputxhtml/outputxhtml.css
@@ -1,204 +1,204 @@
-/*
- * Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.html or http://ckeditor.com/license
- *
- * Styles used by the XHTML 1.1 sample page (xhtml.html).
- */
-
-/**
- * Basic definitions for the editing area.
- */
-body
-{
- font-family: Arial, Verdana, sans-serif;
- font-size: 80%;
- color: #000000;
- background-color: #ffffff;
- padding: 5px;
- margin: 0px;
-}
-
-/**
- * Core styles.
- */
-
-.Bold
-{
- font-weight: bold;
-}
-
-.Italic
-{
- font-style: italic;
-}
-
-.Underline
-{
- text-decoration: underline;
-}
-
-.StrikeThrough
-{
- text-decoration: line-through;
-}
-
-.Subscript
-{
- vertical-align: sub;
- font-size: smaller;
-}
-
-.Superscript
-{
- vertical-align: super;
- font-size: smaller;
-}
-
-/**
- * Font faces.
- */
-
-.FontComic
-{
- font-family: 'Comic Sans MS';
-}
-
-.FontCourier
-{
- font-family: 'Courier New';
-}
-
-.FontTimes
-{
- font-family: 'Times New Roman';
-}
-
-/**
- * Font sizes.
- */
-
-.FontSmaller
-{
- font-size: smaller;
-}
-
-.FontLarger
-{
- font-size: larger;
-}
-
-.FontSmall
-{
- font-size: 8pt;
-}
-
-.FontBig
-{
- font-size: 14pt;
-}
-
-.FontDouble
-{
- font-size: 200%;
-}
-
-/**
- * Font colors.
- */
-.FontColor1
-{
- color: #ff9900;
-}
-
-.FontColor2
-{
- color: #0066cc;
-}
-
-.FontColor3
-{
- color: #ff0000;
-}
-
-.FontColor1BG
-{
- background-color: #ff9900;
-}
-
-.FontColor2BG
-{
- background-color: #0066cc;
-}
-
-.FontColor3BG
-{
- background-color: #ff0000;
-}
-
-/**
- * Indentation.
- */
-
-.Indent1
-{
- margin-left: 40px;
-}
-
-.Indent2
-{
- margin-left: 80px;
-}
-
-.Indent3
-{
- margin-left: 120px;
-}
-
-/**
- * Alignment.
- */
-
-.JustifyLeft
-{
- text-align: left;
-}
-
-.JustifyRight
-{
- text-align: right;
-}
-
-.JustifyCenter
-{
- text-align: center;
-}
-
-.JustifyFull
-{
- text-align: justify;
-}
-
-/**
- * Other.
- */
-
-code
-{
- font-family: courier, monospace;
- background-color: #eeeeee;
- padding-left: 1px;
- padding-right: 1px;
- border: #c0c0c0 1px solid;
-}
-
-kbd
-{
- padding: 0px 1px 0px 1px;
- border-width: 1px 2px 2px 1px;
- border-style: solid;
-}
-
-blockquote
-{
- color: #808080;
-}
+/*
+ * Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or http://ckeditor.com/license
+ *
+ * Styles used by the XHTML 1.1 sample page (xhtml.html).
+ */
+
+/**
+ * Basic definitions for the editing area.
+ */
+body
+{
+ font-family: Arial, Verdana, sans-serif;
+ font-size: 80%;
+ color: #000000;
+ background-color: #ffffff;
+ padding: 5px;
+ margin: 0px;
+}
+
+/**
+ * Core styles.
+ */
+
+.Bold
+{
+ font-weight: bold;
+}
+
+.Italic
+{
+ font-style: italic;
+}
+
+.Underline
+{
+ text-decoration: underline;
+}
+
+.StrikeThrough
+{
+ text-decoration: line-through;
+}
+
+.Subscript
+{
+ vertical-align: sub;
+ font-size: smaller;
+}
+
+.Superscript
+{
+ vertical-align: super;
+ font-size: smaller;
+}
+
+/**
+ * Font faces.
+ */
+
+.FontComic
+{
+ font-family: 'Comic Sans MS';
+}
+
+.FontCourier
+{
+ font-family: 'Courier New';
+}
+
+.FontTimes
+{
+ font-family: 'Times New Roman';
+}
+
+/**
+ * Font sizes.
+ */
+
+.FontSmaller
+{
+ font-size: smaller;
+}
+
+.FontLarger
+{
+ font-size: larger;
+}
+
+.FontSmall
+{
+ font-size: 8pt;
+}
+
+.FontBig
+{
+ font-size: 14pt;
+}
+
+.FontDouble
+{
+ font-size: 200%;
+}
+
+/**
+ * Font colors.
+ */
+.FontColor1
+{
+ color: #ff9900;
+}
+
+.FontColor2
+{
+ color: #0066cc;
+}
+
+.FontColor3
+{
+ color: #ff0000;
+}
+
+.FontColor1BG
+{
+ background-color: #ff9900;
+}
+
+.FontColor2BG
+{
+ background-color: #0066cc;
+}
+
+.FontColor3BG
+{
+ background-color: #ff0000;
+}
+
+/**
+ * Indentation.
+ */
+
+.Indent1
+{
+ margin-left: 40px;
+}
+
+.Indent2
+{
+ margin-left: 80px;
+}
+
+.Indent3
+{
+ margin-left: 120px;
+}
+
+/**
+ * Alignment.
+ */
+
+.JustifyLeft
+{
+ text-align: left;
+}
+
+.JustifyRight
+{
+ text-align: right;
+}
+
+.JustifyCenter
+{
+ text-align: center;
+}
+
+.JustifyFull
+{
+ text-align: justify;
+}
+
+/**
+ * Other.
+ */
+
+code
+{
+ font-family: courier, monospace;
+ background-color: #eeeeee;
+ padding-left: 1px;
+ padding-right: 1px;
+ border: #c0c0c0 1px solid;
+}
+
+kbd
+{
+ padding: 0px 1px 0px 1px;
+ border-width: 1px 2px 2px 1px;
+ border-style: solid;
+}
+
+blockquote
+{
+ color: #808080;
+}
diff --git a/samples/assets/posteddata.php b/samples/assets/posteddata.php
index bb45656..32c3a44 100644..100755
--- a/samples/assets/posteddata.php
+++ b/samples/assets/posteddata.php
@@ -1,59 +1,59 @@
-<!DOCTYPE html>
-<?php
-/*
-Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.html or http://ckeditor.com/license
-*/
-?>
-<html>
-<head>
- <meta charset="utf-8">
- <title>Sample &mdash; CKEditor</title>
- <link rel="stylesheet" href="sample.css">
-</head>
-<body>
- <h1 class="samples">
- CKEditor &mdash; Posted Data
- </h1>
- <table border="1" cellspacing="0" id="outputSample">
- <colgroup><col width="120"></colgroup>
- <thead>
- <tr>
- <th>Field&nbsp;Name</th>
- <th>Value</th>
- </tr>
- </thead>
-<?php
-
-if (!empty($_POST))
-{
- foreach ( $_POST as $key => $value )
- {
- if ( ( !is_string($value) && !is_numeric($value) ) || !is_string($key) )
- continue;
-
- if ( get_magic_quotes_gpc() )
- $value = htmlspecialchars( stripslashes((string)$value) );
- else
- $value = htmlspecialchars( (string)$value );
-?>
- <tr>
- <th style="vertical-align: top"><?php echo htmlspecialchars( (string)$key ); ?></th>
- <td><pre class="samples"><?php echo $value; ?></pre></td>
- </tr>
- <?php
- }
-}
-?>
- </table>
- <div id="footer">
- <hr>
- <p>
- CKEditor - The text editor for the Internet - <a class="samples" href="http://ckeditor.com/">http://ckeditor.com</a>
- </p>
- <p id="copy">
- Copyright &copy; 2003-2013, <a class="samples" href="http://cksource.com/">CKSource</a> - Frederico Knabben. All rights reserved.
- </p>
- </div>
-</body>
-</html>
+<!DOCTYPE html>
+<?php
+/*
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or http://ckeditor.com/license
+*/
+?>
+<html>
+<head>
+ <meta charset="utf-8">
+ <title>Sample &mdash; CKEditor</title>
+ <link rel="stylesheet" href="sample.css">
+</head>
+<body>
+ <h1 class="samples">
+ CKEditor &mdash; Posted Data
+ </h1>
+ <table border="1" cellspacing="0" id="outputSample">
+ <colgroup><col width="120"></colgroup>
+ <thead>
+ <tr>
+ <th>Field&nbsp;Name</th>
+ <th>Value</th>
+ </tr>
+ </thead>
+<?php
+
+if (!empty($_POST))
+{
+ foreach ( $_POST as $key => $value )
+ {
+ if ( ( !is_string($value) && !is_numeric($value) ) || !is_string($key) )
+ continue;
+
+ if ( get_magic_quotes_gpc() )
+ $value = htmlspecialchars( stripslashes((string)$value) );
+ else
+ $value = htmlspecialchars( (string)$value );
+?>
+ <tr>
+ <th style="vertical-align: top"><?php echo htmlspecialchars( (string)$key ); ?></th>
+ <td><pre class="samples"><?php echo $value; ?></pre></td>
+ </tr>
+ <?php
+ }
+}
+?>
+ </table>
+ <div id="footer">
+ <hr>
+ <p>
+ CKEditor - The text editor for the Internet - <a class="samples" href="http://ckeditor.com/">http://ckeditor.com</a>
+ </p>
+ <p id="copy">
+ Copyright &copy; 2003-2013, <a class="samples" href="http://cksource.com/">CKSource</a> - Frederico Knabben. All rights reserved.
+ </p>
+ </div>
+</body>
+</html>
diff --git a/samples/assets/uilanguages/languages.js b/samples/assets/uilanguages/languages.js
index f0c536d..6255d91 100644..100755
--- a/samples/assets/uilanguages/languages.js
+++ b/samples/assets/uilanguages/languages.js
@@ -1,85 +1,7 @@
-/**
- * @license Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.html or http://ckeditor.com/license
- */
-
-var CKEDITOR_LANGS = (function() {
- var langs = {
- af: 'Afrikaans',
- ar: 'Arabic',
- bg: 'Bulgarian',
- bn: 'Bengali/Bangla',
- bs: 'Bosnian',
- ca: 'Catalan',
- cs: 'Czech',
- cy: 'Welsh',
- da: 'Danish',
- de: 'German',
- el: 'Greek',
- en: 'English',
- 'en-au': 'English (Australia)',
- 'en-ca': 'English (Canadian)',
- 'en-gb': 'English (United Kingdom)',
- eo: 'Esperanto',
- es: 'Spanish',
- et: 'Estonian',
- eu: 'Basque',
- fa: 'Persian',
- fi: 'Finnish',
- fo: 'Faroese',
- fr: 'French',
- 'fr-ca': 'French (Canada)',
- gl: 'Galician',
- gu: 'Gujarati',
- he: 'Hebrew',
- hi: 'Hindi',
- hr: 'Croatian',
- hu: 'Hungarian',
- is: 'Icelandic',
- it: 'Italian',
- ja: 'Japanese',
- ka: 'Georgian',
- km: 'Khmer',
- ko: 'Korean',
- ku : 'Kurdish',
- lt: 'Lithuanian',
- lv: 'Latvian',
- mk: 'Macedonian',
- mn: 'Mongolian',
- ms: 'Malay',
- nb: 'Norwegian Bokmal',
- nl: 'Dutch',
- no: 'Norwegian',
- pl: 'Polish',
- pt: 'Portuguese (Portugal)',
- 'pt-br': 'Portuguese (Brazil)',
- ro: 'Romanian',
- ru: 'Russian',
- si: 'Sinhala',
- sk: 'Slovak',
- sq : 'Albanian',
- sl: 'Slovenian',
- sr: 'Serbian (Cyrillic)',
- 'sr-latn': 'Serbian (Latin)',
- sv: 'Swedish',
- th: 'Thai',
- tr: 'Turkish',
- ug: 'Uighur',
- uk: 'Ukrainian',
- vi: 'Vietnamese',
- zh: 'Chinese Traditional',
- 'zh-cn': 'Chinese Simplified'
- };
-
- var langsArray = [];
-
- for ( var code in CKEDITOR.lang.languages ) {
- langsArray.push({ code: code, name: ( langs[ code ] || code ) } );
- }
-
- langsArray.sort( function( a, b ) {
- return ( a.name < b.name ) ? -1 : 1;
- });
-
- return langsArray;
-})();
+/*
+ Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+ For licensing, see LICENSE.md or http://ckeditor.com/license
+*/
+var CKEDITOR_LANGS=function(){var c={af:"Afrikaans",ar:"Arabic",bg:"Bulgarian",bn:"Bengali/Bangla",bs:"Bosnian",ca:"Catalan",cs:"Czech",cy:"Welsh",da:"Danish",de:"German",el:"Greek",en:"English","en-au":"English (Australia)","en-ca":"English (Canadian)","en-gb":"English (United Kingdom)",eo:"Esperanto",es:"Spanish",et:"Estonian",eu:"Basque",fa:"Persian",fi:"Finnish",fo:"Faroese",fr:"French","fr-ca":"French (Canada)",gl:"Galician",gu:"Gujarati",he:"Hebrew",hi:"Hindi",hr:"Croatian",hu:"Hungarian",id:"Indonesian",
+is:"Icelandic",it:"Italian",ja:"Japanese",ka:"Georgian",km:"Khmer",ko:"Korean",ku:"Kurdish",lt:"Lithuanian",lv:"Latvian",mk:"Macedonian",mn:"Mongolian",ms:"Malay",nb:"Norwegian Bokmal",nl:"Dutch",no:"Norwegian",pl:"Polish",pt:"Portuguese (Portugal)","pt-br":"Portuguese (Brazil)",ro:"Romanian",ru:"Russian",si:"Sinhala",sk:"Slovak",sq:"Albanian",sl:"Slovenian",sr:"Serbian (Cyrillic)","sr-latn":"Serbian (Latin)",sv:"Swedish",th:"Thai",tr:"Turkish",ug:"Uighur",uk:"Ukrainian",vi:"Vietnamese",zh:"Chinese Traditional",
+"zh-cn":"Chinese Simplified"},b=[],a;for(a in CKEDITOR.lang.languages)b.push({code:a,name:c[a]||a});b.sort(function(a,b){return a.name<b.name?-1:1});return b}(); \ No newline at end of file
diff --git a/samples/index.html b/samples/index.html
index 71ea8e8..73cdc15 100644..100755
--- a/samples/index.html
+++ b/samples/index.html
@@ -1,102 +1,140 @@
-<!DOCTYPE html>
-<!--
-Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.html or http://ckeditor.com/license
--->
-<html>
-<head>
- <title>CKEditor Samples</title>
- <meta charset="utf-8">
- <link rel="stylesheet" href="sample.css">
-</head>
-<body>
- <h1 class="samples">
- CKEditor Samples
- </h1>
- <div class="twoColumns">
- <div class="twoColumnsLeft">
- <h2 class="samples">
- Basic Samples
- </h2>
- <dl class="samples">
- <dt><a class="samples" href="replacebyclass.html">Replace textarea elements by class name</a></dt>
- <dd>Automatic replacement of all textarea elements of a given class with a CKEditor instance.</dd>
+<!DOCTYPE html>
+<!--
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or http://ckeditor.com/license
+-->
+<html>
+<head>
+ <title>CKEditor Samples</title>
+ <meta charset="utf-8">
+ <link rel="stylesheet" href="sample.css">
+</head>
+<body>
+ <h1 class="samples">
+ CKEditor Samples
+ </h1>
+ <div class="twoColumns">
+ <div class="twoColumnsLeft">
+ <h2 class="samples">
+ Basic Samples
+ </h2>
+ <dl class="samples">
+ <dt><a class="samples" href="replacebyclass.html">Replace textarea elements by class name</a></dt>
+ <dd>Automatic replacement of all textarea elements of a given class with a CKEditor instance.</dd>
+
+ <dt><a class="samples" href="replacebycode.html">Replace textarea elements by code</a></dt>
+ <dd>Replacement of textarea elements with CKEditor instances by using a JavaScript call.</dd>
+
+ <dt><a class="samples" href="jquery.html">Create editors with jQuery</a></dt>
+ <dd>Creating standard and inline CKEditor instances with jQuery adapter.</dd>
+ </dl>
+
+ <h2 class="samples">
+ Basic Customization
+ </h2>
+ <dl class="samples">
+ <dt><a class="samples" href="uicolor.html">User Interface color</a></dt>
+ <dd>Changing CKEditor User Interface color and adding a toolbar button that lets the user set the UI color.</dd>
+
+ <dt><a class="samples" href="uilanguages.html">User Interface languages</a></dt>
+ <dd>Changing CKEditor User Interface language and adding a drop-down list that lets the user choose the UI language.</dd>
+ </dl>
+
+
+ <h2 class="samples">Plugins</h2>
+<dl class="samples">
+<dt><a class="samples" href="plugins/image2/image2.html">New Image plugin</a><span class="new">New!</span></dt>
+<dd>Using the new Image plugin to insert captioned images and adjust their dimensions.</dd>
- <dt><a class="samples" href="replacebycode.html">Replace textarea elements by code</a></dt>
- <dd>Replacement of textarea elements with CKEditor instances by using a JavaScript call.</dd>
- </dl>
+<dt><a class="samples" href="plugins/sourcedialog/sourcedialog.html">Editing source code in a dialog</a><span class="new">New!</span></dt>
+<dd>Editing HTML content of both inline and framed editor instances.</dd>
- <h2 class="samples">
- Basic Customization
- </h2>
- <dl class="samples">
- <dt><a class="samples" href="uicolor.html">User Interface color</a></dt>
- <dd>Changing CKEditor User Interface color and adding a toolbar button that lets the user set the UI color.</dd>
+<dt><a class="samples" href="plugins/devtools/devtools.html">Developer Tools plugin</a></dt>
+<dd>Using the Developer Tools plugin to display information about dialog window UI elements to allow for easier customization.</dd>
- <dt><a class="samples" href="uilanguages.html">User Interface languages</a></dt>
- <dd>Changing CKEditor User Interface language and adding a drop-down list that lets the user choose the UI language.</dd>
- </dl>
+<dt><a class="samples" href="plugins/magicline/magicline.html">Magicline plugin</a></dt>
+<dd>Using the Magicline plugin to access difficult focus spaces.</dd>
+<dt><a class="samples" href="plugins/stylesheetparser/stylesheetparser.html">Stylesheet Parser plugin</a></dt>
+<dd>Using the Stylesheet Parser plugin to fill the Styles drop-down list based on the CSS classes available in the document stylesheet.</dd>
+<dt><a class="samples" href="plugins/wysiwygarea/fullpage.html">Full page support</a></dt>
+<dd>CKEditor inserted with a JavaScript call and used to edit the whole page from &lt;html&gt; to &lt;/html&gt;.</dd>
+</dl>
+ </div>
+ <div class="twoColumnsRight">
+ <h2 class="samples">
+ Inline Editing
+ </h2>
+ <dl class="samples">
+ <dt><a class="samples" href="inlineall.html">Massive inline editor creation</a></dt>
+ <dd>Turn all elements with <code>contentEditable = true</code> attribute into inline editors.</dd>
+
+ <dt><a class="samples" href="inlinebycode.html">Convert element into an inline editor by code</a></dt>
+ <dd>Conversion of DOM elements into inline CKEditor instances by using a JavaScript call.</dd>
+
+ <dt><a class="samples" href="inlinetextarea.html">Replace textarea with inline editor</a> <span class="new">New!</span></dt>
+ <dd>A form with a textarea that is replaced by an inline editor at runtime.</dd>
+
+
+ </dl>
+
+ <h2 class="samples">
+ Advanced Samples
+ </h2>
+ <dl class="samples">
+ <dt><a class="samples" href="datafiltering.html">Data filtering and features activation</a> <span class="new">New!</span></dt>
+ <dd>Data filtering and automatic features activation basing on configuration.</dd>
+
+ <dt><a class="samples" href="divreplace.html">Replace DIV elements on the fly</a></dt>
+ <dd>Transforming a <code>div</code> element into an instance of CKEditor with a mouse click.</dd>
+
+ <dt><a class="samples" href="appendto.html">Append editor instances</a></dt>
+ <dd>Appending editor instances to existing DOM elements.</dd>
+
+ <dt><a class="samples" href="ajax.html">Create and destroy editor instances for Ajax applications</a></dt>
+ <dd>Creating and destroying CKEditor instances on the fly and saving the contents entered into the editor window.</dd>
+
+ <dt><a class="samples" href="api.html">Basic usage of the API</a></dt>
+ <dd>Using the CKEditor JavaScript API to interact with the editor at runtime.</dd>
+
+ <dt><a class="samples" href="xhtmlstyle.html">XHTML-compliant style</a></dt>
+ <dd>Configuring CKEditor to produce XHTML 1.1 compliant attributes and styles.</dd>
+
+ <dt><a class="samples" href="readonly.html">Read-only mode</a></dt>
+ <dd>Using the readOnly API to block introducing changes to the editor contents.</dd>
+
+ <dt><a class="samples" href="tabindex.html">"Tab" key-based navigation</a></dt>
+ <dd>Navigating among editor instances with tab key.</dd>
+
+
+
+<dt><a class="samples" href="plugins/dialog/dialog.html">Using the JavaScript API to customize dialog windows</a></dt>
+<dd>Using the dialog windows API to customize dialog windows without changing the original editor code.</dd>
- <!-- PLUGINS_SAMPLES -->
- </div>
- <div class="twoColumnsRight">
- <h2 class="samples">
- Inline Editing <span class="new">New!</span>
- </h2>
- <dl class="samples">
- <dt><a class="samples" href="inlineall.html">Massive inline editor creation</a> <span class="new">New!</span></dt>
- <dd>Turn all elements with <code>contentEditable = true</code> attribute into inline editors.</dd>
+<dt><a class="samples" href="plugins/enterkey/enterkey.html">Using the &quot;Enter&quot; key in CKEditor</a></dt>
+<dd>Configuring the behavior of <em>Enter</em> and <em>Shift+Enter</em> keys.</dd>
- <dt><a class="samples" href="inlinebycode.html">Convert element into an inline editor by code</a> <span class="new">New!</span></dt>
- <dd>Conversion of DOM elements into inline CKEditor instances by using a JavaScript call.</dd>
+<dt><a class="samples" href="plugins/htmlwriter/outputforflash.html">Output for Flash</a></dt>
+<dd>Configuring CKEditor to produce HTML code that can be used with Adobe Flash.</dd>
- <!-- INLINE_EDITING_SAMPLES -->
- </dl>
+<dt><a class="samples" href="plugins/htmlwriter/outputhtml.html">Output HTML</a></dt>
+<dd>Configuring CKEditor to produce legacy HTML 4 code.</dd>
- <h2 class="samples">
- Advanced Samples
- </h2>
- <dl class="samples">
- <dt><a class="samples" href="datafiltering.html">Data filtering and features activation</a> <span class="new">New!</span></dt>
- <dd>Data filtering and automatic features activation basing on configuration.</dd>
-
- <dt><a class="samples" href="divreplace.html">Replace DIV elements on the fly</a></dt>
- <dd>Transforming a <code>div</code> element into an instance of CKEditor with a mouse click.</dd>
-
- <dt><a class="samples" href="appendto.html">Append editor instances</a></dt>
- <dd>Appending editor instances to existing DOM elements.</dd>
-
- <dt><a class="samples" href="ajax.html">Create and destroy editor instances for Ajax applications</a></dt>
- <dd>Creating and destroying CKEditor instances on the fly and saving the contents entered into the editor window.</dd>
-
- <dt><a class="samples" href="api.html">Basic usage of the API</a></dt>
- <dd>Using the CKEditor JavaScript API to interact with the editor at runtime.</dd>
-
- <dt><a class="samples" href="xhtmlstyle.html">XHTML-compliant style</a></dt>
- <dd>Configuring CKEditor to produce XHTML 1.1 compliant attributes and styles.</dd>
-
- <dt><a class="samples" href="readonly.html">Read-only mode</a></dt>
- <dd>Using the readOnly API to block introducing changes to the editor contents.</dd>
-
- <dt><a class="samples" href="tabindex.html">"Tab" key-based navigation</a> <span class="new">New!</span></dt>
- <dd>Navigating among editor instances with tab key.</dd>
-
-
-
- <!-- ADVANCED_SAMPLES -->
- </dl>
- </div>
- </div>
- <div id="footer">
- <hr>
- <p>
- CKEditor - The text editor for the Internet - <a class="samples" href="http://ckeditor.com/">http://ckeditor.com</a>
- </p>
- <p id="copy">
- Copyright &copy; 2003-2013, <a class="samples" href="http://cksource.com/">CKSource</a> - Frederico Knabben. All rights reserved.
- </p>
- </div>
-</body>
-</html>
+<dt><a class="samples" href="plugins/toolbar/toolbar.html">Toolbar Configurations</a></dt>
+<dd>Configuring CKEditor to display full or custom toolbar layout.</dd>
+
+ </dl>
+ </div>
+ </div>
+ <div id="footer">
+ <hr>
+ <p>
+ CKEditor - The text editor for the Internet - <a class="samples" href="http://ckeditor.com/">http://ckeditor.com</a>
+ </p>
+ <p id="copy">
+ Copyright &copy; 2003-2013, <a class="samples" href="http://cksource.com/">CKSource</a> - Frederico Knabben. All rights reserved.
+ </p>
+ </div>
+</body>
+</html>
diff --git a/samples/sample.css b/samples/sample.css
index 8cb9b76..fea1aa1 100644..100755
--- a/samples/sample.css
+++ b/samples/sample.css
@@ -1,339 +1,356 @@
-/*
-Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.html or http://ckeditor.com/license
-*/
-
-html, body, h1, h2, h3, h4, h5, h6, div, span, blockquote, p, address, form, fieldset, img, ul, ol, dl, dt, dd, li, hr, table, td, th, strong, em, sup, sub, dfn, ins, del, q, cite, var, samp, code, kbd, tt, pre
-{
- line-height: 1.5em;
-}
-
-body
-{
- padding: 10px 30px;
-}
-
-input, textarea, select, option, optgroup, button, td, th
-{
- font-size: 100%;
-}
-
-pre, code, kbd, samp, tt
-{
- font-family: monospace,monospace;
- font-size: 1em;
-}
-
-body {
- width: 960px;
- margin: 0 auto;
-}
-
-code
-{
- background: #f3f3f3;
- border: 1px solid #ddd;
- padding: 1px 4px;
-
- -moz-border-radius: 3px;
- -webkit-border-radius: 3px;
- border-radius: 3px;
-}
-
-abbr
-{
- border-bottom: 1px dotted #555;
- cursor: pointer;
-}
-
-.new
-{
- background: #FF7E00;
- border: 1px solid #DA8028;
- color: #fff;
- font-size: 10px;
- font-weight: bold;
- padding: 1px 4px;
- text-shadow: 0 1px 0 #C97626;
- text-transform: uppercase;
- margin: 0 0 0 3px;
-
- -moz-border-radius: 3px;
- -webkit-border-radius: 3px;
- border-radius: 3px;
-
- -moz-box-shadow: 0 2px 3px 0 #FFA54E inset;
- -webkit-box-shadow: 0 2px 3px 0 #FFA54E inset;
- box-shadow: 0 2px 3px 0 #FFA54E inset;
-}
-
-h1.samples
-{
- color: #0782C1;
- font-size: 200%;
- font-weight: normal;
- margin: 0;
- padding: 0;
-}
-
-h1.samples a
-{
- color: #0782C1;
- text-decoration: none;
- border-bottom: 1px dotted #0782C1;
-}
-
-.samples a:hover
-{
- border-bottom: 1px dotted #0782C1;
-}
-
-h2.samples
-{
- color: #000000;
- font-size: 130%;
- margin: 15px 0 0 0;
- padding: 0;
-}
-
-p, blockquote, address, form, pre, dl, h1.samples, h2.samples
-{
- margin-bottom: 15px;
-}
-
-ul.samples
-{
- margin-bottom: 15px;
-}
-
-.clear
-{
- clear: both;
-}
-
-fieldset
-{
- margin: 0;
- padding: 10px;
-}
-
-body, input, textarea
-{
- color: #333333;
- font-family: Arial, Helvetica, sans-serif;
-}
-
-body
-{
- font-size: 75%;
-}
-
-a.samples
-{
- color: #189DE1;
- text-decoration: none;
-}
-
-form
-{
- margin: 0;
- padding: 0;
-}
-
-pre.samples
-{
- background-color: #F7F7F7;
- border: 1px solid #D7D7D7;
- overflow: auto;
- padding: 0.25em;
- white-space: pre-wrap; /* CSS 2.1 */
- word-wrap: break-word; /* IE7 */
- -moz-tab-size: 4;
- -o-tab-size: 4;
- -webkit-tab-size: 4;
- tab-size: 4;
-}
-
-#footer
-{
- clear: both;
- padding-top: 10px;
-}
-
-#footer hr
-{
- margin: 10px 0 15px 0;
- height: 1px;
- border: solid 1px gray;
- border-bottom: none;
-}
-
-#footer p
-{
- margin: 0 10px 10px 10px;
- float: left;
-}
-
-#footer #copy
-{
- float: right;
-}
-
-#outputSample
-{
- width: 100%;
- table-layout: fixed;
-}
-
-#outputSample thead th
-{
- color: #dddddd;
- background-color: #999999;
- padding: 4px;
- white-space: nowrap;
-}
-
-#outputSample tbody th
-{
- vertical-align: top;
- text-align: left;
-}
-
-#outputSample pre
-{
- margin: 0;
- padding: 0;
-}
-
-.description
-{
- border: 1px dotted #B7B7B7;
- margin-bottom: 10px;
- padding: 10px 10px 0;
- overflow: hidden;
-}
-
-label
-{
- display: block;
- margin-bottom: 6px;
-}
-
-/**
- * CKEditor editables are automatically set with the "cke_editable" class
- * plus cke_editable_(inline|themed) depending on the editor type.
- */
-
-/* Style a bit the inline editables. */
-.cke_editable.cke_editable_inline
-{
- cursor: pointer;
-}
-
-/* Once an editable element gets focused, the "cke_focus" class is
- added to it, so we can style it differently. */
-.cke_editable.cke_editable_inline.cke_focus
-{
- box-shadow: inset 0px 0px 20px 3px #ddd, inset 0 0 1px #000;
- outline: none;
- background: #eee;
- cursor: text;
-}
-
-/* Avoid pre-formatted overflows inline editable. */
-.cke_editable_inline pre
-{
- white-space: pre-wrap;
- word-wrap: break-word;
-}
-
-/**
- * Samples index styles.
- */
-
-.twoColumns,
-.twoColumnsLeft,
-.twoColumnsRight
-{
- overflow: hidden;
-}
-
-.twoColumnsLeft,
-.twoColumnsRight
-{
- width: 45%;
-}
-
-.twoColumnsLeft
-{
- float: left;
-}
-
-.twoColumnsRight
-{
- float: right;
-}
-
-dl.samples
-{
- padding: 0 0 0 40px;
-}
-dl.samples > dt
-{
- display: list-item;
- list-style-type: disc;
- list-style-position: outside;
- margin: 0 0 3px;
-}
-dl.samples > dd
-{
- margin: 0 0 3px;
-}
-.warning
-{
- color: #ff0000;
- background-color: #FFCCBA;
- border: 2px dotted #ff0000;
- padding: 15px 10px;
- margin: 10px 0;
-}
-
-/* Used on inline samples */
-
-blockquote
-{
- font-style: italic;
- font-family: Georgia, Times, "Times New Roman", serif;
- padding: 2px 0;
- border-style: solid;
- border-color: #ccc;
- border-width: 0;
-}
-
-.cke_contents_ltr blockquote
-{
- padding-left: 20px;
- padding-right: 8px;
- border-left-width: 5px;
-}
-
-.cke_contents_rtl blockquote
-{
- padding-left: 8px;
- padding-right: 20px;
- border-right-width: 5px;
-}
-
-img.right {
- border: 1px solid #ccc;
- float: right;
- margin-left: 15px;
- padding: 5px;
-}
-
-img.left {
- border: 1px solid #ccc;
- float: left;
- margin-right: 15px;
- padding: 5px;
-}
+/*
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or http://ckeditor.com/license
+*/
+
+html, body, h1, h2, h3, h4, h5, h6, div, span, blockquote, p, address, form, fieldset, img, ul, ol, dl, dt, dd, li, hr, table, td, th, strong, em, sup, sub, dfn, ins, del, q, cite, var, samp, code, kbd, tt, pre
+{
+ line-height: 1.5em;
+}
+
+body
+{
+ padding: 10px 30px;
+}
+
+input, textarea, select, option, optgroup, button, td, th
+{
+ font-size: 100%;
+}
+
+pre, code, kbd, samp, tt
+{
+ font-family: monospace,monospace;
+ font-size: 1em;
+}
+
+body {
+ width: 960px;
+ margin: 0 auto;
+}
+
+code
+{
+ background: #f3f3f3;
+ border: 1px solid #ddd;
+ padding: 1px 4px;
+
+ -moz-border-radius: 3px;
+ -webkit-border-radius: 3px;
+ border-radius: 3px;
+}
+
+abbr
+{
+ border-bottom: 1px dotted #555;
+ cursor: pointer;
+}
+
+.new, .beta
+{
+ text-transform: uppercase;
+ font-size: 10px;
+ font-weight: bold;
+ padding: 1px 4px;
+ margin: 0 0 0 5px;
+ color: #fff;
+ float: right;
+
+ -moz-border-radius: 3px;
+ -webkit-border-radius: 3px;
+ border-radius: 3px;
+}
+
+.new
+{
+ background: #FF7E00;
+ border: 1px solid #DA8028;
+ text-shadow: 0 1px 0 #C97626;
+
+ -moz-box-shadow: 0 2px 3px 0 #FFA54E inset;
+ -webkit-box-shadow: 0 2px 3px 0 #FFA54E inset;
+ box-shadow: 0 2px 3px 0 #FFA54E inset;
+}
+
+.beta
+{
+ background: #18C0DF;
+ border: 1px solid #19AAD8;
+ text-shadow: 0 1px 0 #048CAD;
+ font-style: italic;
+
+ -moz-box-shadow: 0 2px 3px 0 #50D4FD inset;
+ -webkit-box-shadow: 0 2px 3px 0 #50D4FD inset;
+ box-shadow: 0 2px 3px 0 #50D4FD inset;
+}
+
+h1.samples
+{
+ color: #0782C1;
+ font-size: 200%;
+ font-weight: normal;
+ margin: 0;
+ padding: 0;
+}
+
+h1.samples a
+{
+ color: #0782C1;
+ text-decoration: none;
+ border-bottom: 1px dotted #0782C1;
+}
+
+.samples a:hover
+{
+ border-bottom: 1px dotted #0782C1;
+}
+
+h2.samples
+{
+ color: #000000;
+ font-size: 130%;
+ margin: 15px 0 0 0;
+ padding: 0;
+}
+
+p, blockquote, address, form, pre, dl, h1.samples, h2.samples
+{
+ margin-bottom: 15px;
+}
+
+ul.samples
+{
+ margin-bottom: 15px;
+}
+
+.clear
+{
+ clear: both;
+}
+
+fieldset
+{
+ margin: 0;
+ padding: 10px;
+}
+
+body, input, textarea
+{
+ color: #333333;
+ font-family: Arial, Helvetica, sans-serif;
+}
+
+body
+{
+ font-size: 75%;
+}
+
+a.samples
+{
+ color: #189DE1;
+ text-decoration: none;
+}
+
+form
+{
+ margin: 0;
+ padding: 0;
+}
+
+pre.samples
+{
+ background-color: #F7F7F7;
+ border: 1px solid #D7D7D7;
+ overflow: auto;
+ padding: 0.25em;
+ white-space: pre-wrap; /* CSS 2.1 */
+ word-wrap: break-word; /* IE7 */
+ -moz-tab-size: 4;
+ -o-tab-size: 4;
+ -webkit-tab-size: 4;
+ tab-size: 4;
+}
+
+#footer
+{
+ clear: both;
+ padding-top: 10px;
+}
+
+#footer hr
+{
+ margin: 10px 0 15px 0;
+ height: 1px;
+ border: solid 1px gray;
+ border-bottom: none;
+}
+
+#footer p
+{
+ margin: 0 10px 10px 10px;
+ float: left;
+}
+
+#footer #copy
+{
+ float: right;
+}
+
+#outputSample
+{
+ width: 100%;
+ table-layout: fixed;
+}
+
+#outputSample thead th
+{
+ color: #dddddd;
+ background-color: #999999;
+ padding: 4px;
+ white-space: nowrap;
+}
+
+#outputSample tbody th
+{
+ vertical-align: top;
+ text-align: left;
+}
+
+#outputSample pre
+{
+ margin: 0;
+ padding: 0;
+}
+
+.description
+{
+ border: 1px dotted #B7B7B7;
+ margin-bottom: 10px;
+ padding: 10px 10px 0;
+ overflow: hidden;
+}
+
+label
+{
+ display: block;
+ margin-bottom: 6px;
+}
+
+/**
+ * CKEditor editables are automatically set with the "cke_editable" class
+ * plus cke_editable_(inline|themed) depending on the editor type.
+ */
+
+/* Style a bit the inline editables. */
+.cke_editable.cke_editable_inline
+{
+ cursor: pointer;
+}
+
+/* Once an editable element gets focused, the "cke_focus" class is
+ added to it, so we can style it differently. */
+.cke_editable.cke_editable_inline.cke_focus
+{
+ box-shadow: inset 0px 0px 20px 3px #ddd, inset 0 0 1px #000;
+ outline: none;
+ background: #eee;
+ cursor: text;
+}
+
+/* Avoid pre-formatted overflows inline editable. */
+.cke_editable_inline pre
+{
+ white-space: pre-wrap;
+ word-wrap: break-word;
+}
+
+/**
+ * Samples index styles.
+ */
+
+.twoColumns,
+.twoColumnsLeft,
+.twoColumnsRight
+{
+ overflow: hidden;
+}
+
+.twoColumnsLeft,
+.twoColumnsRight
+{
+ width: 45%;
+}
+
+.twoColumnsLeft
+{
+ float: left;
+}
+
+.twoColumnsRight
+{
+ float: right;
+}
+
+dl.samples
+{
+ padding: 0 0 0 40px;
+}
+dl.samples > dt
+{
+ display: list-item;
+ list-style-type: disc;
+ list-style-position: outside;
+ margin: 0 0 3px;
+}
+dl.samples > dd
+{
+ margin: 0 0 3px;
+}
+.warning
+{
+ color: #ff0000;
+ background-color: #FFCCBA;
+ border: 2px dotted #ff0000;
+ padding: 15px 10px;
+ margin: 10px 0;
+}
+
+/* Used on inline samples */
+
+blockquote
+{
+ font-style: italic;
+ font-family: Georgia, Times, "Times New Roman", serif;
+ padding: 2px 0;
+ border-style: solid;
+ border-color: #ccc;
+ border-width: 0;
+}
+
+.cke_contents_ltr blockquote
+{
+ padding-left: 20px;
+ padding-right: 8px;
+ border-left-width: 5px;
+}
+
+.cke_contents_rtl blockquote
+{
+ padding-left: 8px;
+ padding-right: 20px;
+ border-right-width: 5px;
+}
+
+img.right {
+ border: 1px solid #ccc;
+ float: right;
+ margin-left: 15px;
+ padding: 5px;
+}
+
+img.left {
+ border: 1px solid #ccc;
+ float: left;
+ margin-right: 15px;
+ padding: 5px;
+}
diff --git a/samples/sample_posteddata.php b/samples/sample_posteddata.php
index 7d2ff30..bf6ac22 100644..100755
--- a/samples/sample_posteddata.php
+++ b/samples/sample_posteddata.php
@@ -1,16 +1,16 @@
-<?php /* <body><pre>
-
--------------------------------------------------------------------------------------------
- CKEditor - Posted Data
-
- We are sorry, but your Web server does not support the PHP language used in this script.
-
- Please note that CKEditor can be used with any other server-side language than just PHP.
- To save the content created with CKEditor you need to read the POST data on the server
- side and write it to a file or the database.
-
- Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
- For licensing, see LICENSE.html or <a href="http://ckeditor.com/license">http://ckeditor.com/license</a>
--------------------------------------------------------------------------------------------
-
-</pre><div style="display:none"></body> */ include "assets/posteddata.php"; ?>
+<?php /* <body><pre>
+
+-------------------------------------------------------------------------------------------
+ CKEditor - Posted Data
+
+ We are sorry, but your Web server does not support the PHP language used in this script.
+
+ Please note that CKEditor can be used with any other server-side language than just PHP.
+ To save the content created with CKEditor you need to read the POST data on the server
+ side and write it to a file or the database.
+
+ Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+ For licensing, see LICENSE.md or <a href="http://ckeditor.com/license">http://ckeditor.com/license</a>
+-------------------------------------------------------------------------------------------
+
+</pre><div style="display:none"></body> */ include "assets/posteddata.php"; ?>
diff --git a/samples/sample.js b/samples/sample.js
index c67705f..5a486de 100644..100755
--- a/samples/sample.js
+++ b/samples/sample.js
@@ -1,34 +1,50 @@
-/**
- * @license Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.html or http://ckeditor.com/license
- */
-
-// Tool scripts for the sample pages.
-// This file can be ignored and is not required to make use of CKEditor.
-
-(function() {
- // Check for sample compliance.
- CKEDITOR.on( 'instanceReady', function( ev ) {
- var editor = ev.editor,
- meta = CKEDITOR.document.$.getElementsByName( 'ckeditor-sample-required-plugins' ),
- requires = meta.length ? CKEDITOR.dom.element.get( meta[ 0 ] ).getAttribute( 'content' ).split( ',' ) : [],
- missing = [];
-
- if ( requires.length ) {
- for ( var i = 0; i < requires.length; i++ ) {
- if ( !editor.plugins[ requires[ i ] ] )
- missing.push( '<code>' + requires[ i ] + '</code>' );
- }
-
- if ( missing.length ) {
- var warn = CKEDITOR.dom.element.createFromHtml(
- '<div class="warning">' +
- '<span>To fully experience this demo, the ' + missing.join( ', ' ) + ' plugin' + ( missing.length > 1 ? 's are' : ' is' ) + ' required.</span>' +
- '</div>'
- );
- warn.insertBefore( editor.container );
- }
- }
- });
-})();
-// %LEAVE_UNMINIFIED% %REMOVE_LINE% \ No newline at end of file
+/**
+ * Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or http://ckeditor.com/license
+ */
+
+// Tool scripts for the sample pages.
+// This file can be ignored and is not required to make use of CKEditor.
+
+(function() {
+ CKEDITOR.on( 'instanceReady', function( ev ) {
+ // Check for sample compliance.
+ var editor = ev.editor,
+ meta = CKEDITOR.document.$.getElementsByName( 'ckeditor-sample-required-plugins' ),
+ requires = meta.length ? CKEDITOR.dom.element.get( meta[ 0 ] ).getAttribute( 'content' ).split( ',' ) : [],
+ missing = [],
+ i;
+
+ if ( requires.length ) {
+ for ( i = 0; i < requires.length; i++ ) {
+ if ( !editor.plugins[ requires[ i ] ] )
+ missing.push( '<code>' + requires[ i ] + '</code>' );
+ }
+
+ if ( missing.length ) {
+ var warn = CKEDITOR.dom.element.createFromHtml(
+ '<div class="warning">' +
+ '<span>To fully experience this demo, the ' + missing.join( ', ' ) + ' plugin' + ( missing.length > 1 ? 's are' : ' is' ) + ' required.</span>' +
+ '</div>'
+ );
+ warn.insertBefore( editor.container );
+ }
+ }
+
+ // Set icons.
+ var doc = new CKEDITOR.dom.document( document ),
+ icons = doc.find( '.button_icon' );
+
+ for ( i = 0; i < icons.count(); i++ ) {
+ var icon = icons.getItem( i ),
+ name = icon.getAttribute( 'data-icon' ),
+ style = CKEDITOR.skin.getIconStyle( name, ( CKEDITOR.lang.dir == 'rtl' ) );
+
+ icon.addClass( 'cke_button_icon' );
+ icon.addClass( 'cke_button__' + name + '_icon' );
+ icon.setAttribute( 'style', style );
+ icon.setStyle( 'float', 'none' );
+
+ }
+ } );
+})();